@@ -381,11 +381,11 @@ option values:
 pattern
   used to match test names using a unix-like file path pattern that supports wildcards
     '/' path level separator
-    '*' matches everything
+    '*' matches any zero or more characters including '/' path level separator
     '?' matches any single character
     '[seq]' matches any character in seq
     '[!seq]' matches any character not in seq
-    ':' matches anything at the current path level
+    ':' matches any one or more characters but not including '/' path level separator
   for a literal match, wrap the meta-characters in brackets where '[?]' matches the character '?'
 
 type
@@ -1371,20 +1371,28 @@ class TestDecorator(object):
 
     def __init__(self, func):
         self.func = func
-        functools.update_wrapper(self, self.func)
 
         self.func.type = self.type.type
         self.func.name = getattr(self.func, "name", self.func.__name__.replace("_", " "))
         self.func.description = getattr(self.func, "description", self.func.__doc__)
 
+        signature = inspect.signature(self.func)
+
+        args = getattr(self.func, "args", {})
+        default_args = {p.name: p.default for p in signature.parameters.values() if
+            p.default != inspect.Parameter.empty}
+
+        self.func.args = default_args
+        self.func.args.update(args)
+
         kwargs = dict(vars(self.func))
 
-        signature = inspect.signature(self.func)
-        kwargs["args"] = {p.name: p.default for p in signature.parameters.values() if
-                          p.default != inspect.Parameter.empty}
-
         self.func.kwargs = kwargs
 
+        _type = self.type
+        functools.update_wrapper(self, self.func)
+        self.type = _type
+
     def __call__(self, *pargs, **args):
         if pargs:
             raise TypeError(f"only named arguments are allowed but {pargs} positional arguments were passed")
